import pyb
import lcd160cr
from random import randint, choice, uniform

lcd = lcd160cr.LCD160CR('X')

MAX_DEPTH = 4
RED = lcd.rgb(255, 0, 0)
YELLOW = lcd.rgb(255, 255, 0)
BLUE = lcd.rgb(0, 0, 255)
WHITE = lcd.rgb(255, 255, 255)
BLACK = lcd.rgb(0, 0, 0)
COLOURS = [RED, YELLOW, BLUE, WHITE, WHITE, WHITE]


class Node:
    """
    Un noeud d'arborescence du sujet tableau Mondrian.
    """

    def __init__(self, depth=0):
        """
        Choix de la couleur, calcul de profondeur
        et ajout de noeuds enfants si pas trop dense.
        """
        self.colour = choice(COLOURS)
        self.depth = depth + 1
        self.children = []
        if self.depth <= MAX_DEPTH:
            self.direction = choice(['h', 'v'])
            self.divide = uniform(0.1, 0.9)
            self.children.append(Node(self.depth))
            self.children.append(Node(self.depth))

    def draw(self, x, y, w, h):
        """
        Trace ce noeud et ses enfants x fois.
        """
        lcd.set_pen(BLACK, self.colour)
        lcd.rect(x, y, w, h)
        if self.children:
            if self.direction == 'h':
                self.children[0].draw(x, y, int(w * self.divide), h)
                self.children[1].draw(x + int(w * self.divide), y,
                                      int(w * (1.0 - self.divide)), h)
            else:
                self.children[0].draw(x, y, w, int(h * self.divide))
                self.children[1].draw(x, y + int(h * self.divide), w,
                                      int(h * (1.0 - self.divide)))


while True:
    # Produit un nouveau tableau Mondrian au bout de 4-8 sec.
    tree = Node()
    tree.draw(0, 0, lcd.w, lcd.h)
    pyb.delay(randint(4000, 8000))
