import array
import pulseio
import board
import time

# Table de conversion entre Morse et caracteres
TAB_MORSE_CAR = {
    ".-": "A",
    "-...": "B",
    "-.-.": "C",
    "-..": "D",
    ".": "E",
    "..-.": "F",
    "--.": "G",
    "....": "H",
    "..": "I",
    ".---": "J",
    "-.-": "K",
    ".-..": "L",
    "--": "M",
    "-.": "N",
    "---": "O",
    ".--.": "P",
    "--.-": "Q",
    ".-.": "R",
    "...": "S",
    "-": "T",
    "..-": "U",
    "...-": "V",
    ".--": "W",
    "-..-": "X",
    "-.--": "Y",
    "--..": "Z",
    ".----": "1",
    "..---": "2",
    "...--": "3",
    "....-": "4",
    ".....": "5",
    "-....": "6",
    "--...": "7",
    "---..": "8",
    "----.": "9",
    "-----": "0",
}

DUREES = (1000, 2000, 4000, 8000)

def normaliser(brute):
    """
    Requantification des durees brutes
    """
    for val in brute:
        valArrondie = round(val/1000) * 1000
        if valArrondie in DUREES:
            yield valArrondie


def traduire_morse(elements):
    """
    Renvoie le caractere correspondant aux traits et points Morse 
    ou bien un point d'interrogation.
    """
    return TAB_MORSE_CAR.get(''.join(elements), "?")


def decoder(valNormales):
    """
    Renvoie une chaine en partant d'un tablau de valeurs normalisees.
    """
    # Brise une valeur normalisee en mots, caracteres et elements.
    mots = []
    caracs = [] 
    elements = [] 
    for val in valNormales:
        if val == 8000:
            # Nouveau mot. 
            if elements:
                caracs.append(traduire_morse(elements))
            if caracs:
                mots.append(''.join(caracs))
            elements = []
            caracs = []
        elif val == 4000:
            # Nouveau caractere. 
            if elements:
                caracs.append(traduire_morse(elements))
            elements = []
        elif val == 2000:
            # Element trait ('-')
            elements.append('-')
        elif val == 1000:
            # Element point ('.')
            elements.append('.')
    return ' '.join(mots).strip()

ir_in = pulseio.PulseIn(board.REMOTEIN, maxlen=512, idle_state=False)

while True:
    while len(ir_in) == 0:
        time.sleep(1)
    ir_in.pause()
    brutes = [ir_in[i] for i in range(len(ir_in))]
    valNormales = normaliser(brutes)
    msg = decoder(valNormales)
    if msg:
        print(msg)
    ir_in.clear()
    ir_in.resume()
